# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..resampling import ApplyTransformsToPoints


def test_ApplyTransformsToPoints_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        dimension=dict(argstr='--dimensionality %d', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        input_file=dict(
            argstr='--input %s',
            extensions=None,
            mandatory=True,
        ),
        invert_transform_flags=dict(),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        output_file=dict(
            argstr='--output %s',
            hash_files=False,
            name_source=['input_file'],
            name_template='%s_transformed.csv',
        ),
        transforms=dict(
            argstr='%s',
            mandatory=True,
        ),
    )
    inputs = ApplyTransformsToPoints.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ApplyTransformsToPoints_outputs():
    output_map = dict(output_file=dict(extensions=None, ), )
    outputs = ApplyTransformsToPoints.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..minc import Volpad


def test_Volpad_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        auto=dict(argstr='-auto', ),
        auto_freq=dict(argstr='-auto_freq %s', ),
        clobber=dict(
            argstr='-clobber',
            usedefault=True,
        ),
        distance=dict(argstr='-distance %s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        input_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        output_file=dict(
            argstr='%s',
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=['input_file'],
            name_template='%s_volpad.mnc',
            position=-1,
        ),
        smooth=dict(argstr='-smooth', ),
        smooth_distance=dict(argstr='-smooth_distance %s', ),
        verbose=dict(argstr='-verbose', ),
    )
    inputs = Volpad.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Volpad_outputs():
    output_map = dict(output_file=dict(extensions=None, ), )
    outputs = Volpad.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import Resample


def test_Resample_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-i %s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        resampled_file=dict(
            argstr='-o %s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        subjects_dir=dict(),
        voxel_size=dict(
            argstr='-vs %.2f %.2f %.2f',
            mandatory=True,
        ),
    )
    inputs = Resample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Resample_outputs():
    output_map = dict(resampled_file=dict(extensions=None, ), )
    outputs = Resample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import fcsv_to_hdf5


def test_fcsv_to_hdf5_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        landmarkGlobPattern=dict(argstr='--landmarkGlobPattern %s', ),
        landmarkTypesList=dict(
            argstr='--landmarkTypesList %s',
            extensions=None,
        ),
        landmarksInformationFile=dict(
            argstr='--landmarksInformationFile %s',
            hash_files=False,
        ),
        modelFile=dict(
            argstr='--modelFile %s',
            hash_files=False,
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        versionID=dict(argstr='--versionID %s', ),
    )
    inputs = fcsv_to_hdf5.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_fcsv_to_hdf5_outputs():
    output_map = dict(
        landmarksInformationFile=dict(extensions=None, ),
        modelFile=dict(extensions=None, ),
    )
    outputs = fcsv_to_hdf5.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import LabelGeometry


def test_LabelGeometry_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        dimension=dict(
            argstr='%d',
            position=0,
            usedefault=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        intensity_image=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=2,
            usedefault=True,
        ),
        label_image=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        output_file=dict(
            argstr='%s',
            name_source=['label_image'],
            name_template='%s.csv',
            position=3,
        ),
    )
    inputs = LabelGeometry.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_LabelGeometry_outputs():
    output_map = dict(output_file=dict(extensions=None, ), )
    outputs = LabelGeometry.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..fix import FeatureExtractor


def test_FeatureExtractor_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        mel_ica=dict(
            argstr='%s',
            copyfile=False,
            position=-1,
        ),
    )
    inputs = FeatureExtractor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_FeatureExtractor_outputs():
    output_map = dict(mel_ica=dict(
        argstr='%s',
        copyfile=False,
        position=-1,
    ), )
    outputs = FeatureExtractor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import CreateJacobianDeterminantImage


def test_CreateJacobianDeterminantImage_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        deformationField=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        doLogJacobian=dict(
            argstr='%d',
            position=3,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        imageDimension=dict(
            argstr='%d',
            mandatory=True,
            position=0,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        outputImage=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=2,
        ),
        useGeometric=dict(
            argstr='%d',
            position=4,
        ),
    )
    inputs = CreateJacobianDeterminantImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_CreateJacobianDeterminantImage_outputs():
    output_map = dict(jacobian_image=dict(extensions=None, ), )
    outputs = CreateJacobianDeterminantImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..regutils import RegMeasure


def test_RegMeasure_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        flo_file=dict(
            argstr='-flo %s',
            extensions=None,
            mandatory=True,
        ),
        measure_type=dict(
            argstr='-%s',
            mandatory=True,
        ),
        omp_core_val=dict(
            argstr='-omp %i',
            usedefault=True,
        ),
        out_file=dict(
            argstr='-out %s',
            extensions=None,
            name_source=['flo_file'],
            name_template='%s',
        ),
        ref_file=dict(
            argstr='-ref %s',
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = RegMeasure.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_RegMeasure_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = RegMeasure.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import BRAINSLandmarkInitializer


def test_BRAINSLandmarkInitializer_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputFixedLandmarkFilename=dict(
            argstr='--inputFixedLandmarkFilename %s',
            extensions=None,
        ),
        inputMovingLandmarkFilename=dict(
            argstr='--inputMovingLandmarkFilename %s',
            extensions=None,
        ),
        inputWeightFilename=dict(
            argstr='--inputWeightFilename %s',
            extensions=None,
        ),
        outputTransformFilename=dict(
            argstr='--outputTransformFilename %s',
            hash_files=False,
        ),
    )
    inputs = BRAINSLandmarkInitializer.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BRAINSLandmarkInitializer_outputs():
    output_map = dict(outputTransformFilename=dict(extensions=None, ), )
    outputs = BRAINSLandmarkInitializer.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..vista import Vnifti2Image


def test_Vnifti2Image_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        attributes=dict(
            argstr='-attr %s',
            extensions=None,
            position=2,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-in %s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        out_file=dict(
            argstr='-out %s',
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=['in_file'],
            name_template='%s.v',
            position=-1,
        ),
    )
    inputs = Vnifti2Image.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Vnifti2Image_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Vnifti2Image.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import SliceTiming


def test_SliceTiming_inputs():
    input_map = dict(
        in_files=dict(
            copyfile=False,
            field='scans',
            mandatory=True,
        ),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True, ),
        num_slices=dict(
            field='nslices',
            mandatory=True,
        ),
        out_prefix=dict(
            field='prefix',
            usedefault=True,
        ),
        paths=dict(),
        ref_slice=dict(
            field='refslice',
            mandatory=True,
        ),
        slice_order=dict(
            field='so',
            mandatory=True,
        ),
        time_acquisition=dict(
            field='ta',
            mandatory=True,
        ),
        time_repetition=dict(
            field='tr',
            mandatory=True,
        ),
        use_mcr=dict(),
        use_v8struct=dict(
            min_ver='8',
            usedefault=True,
        ),
    )
    inputs = SliceTiming.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SliceTiming_outputs():
    output_map = dict(timecorrected_files=dict(), )
    outputs = SliceTiming.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..misc import CalculateMedian


def test_CalculateMedian_inputs():
    input_map = dict(
        in_files=dict(),
        median_file=dict(),
        median_per_file=dict(usedefault=True, ),
    )
    inputs = CalculateMedian.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_CalculateMedian_outputs():
    output_map = dict(median_files=dict(), )
    outputs = CalculateMedian.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import MRIPretess


def test_MRIPretess_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_filled=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-4,
        ),
        in_norm=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        keep=dict(argstr='-keep', ),
        label=dict(
            argstr='%s',
            mandatory=True,
            position=-3,
            usedefault=True,
        ),
        nocorners=dict(argstr='-nocorners', ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            keep_extension=True,
            name_source=['in_filled'],
            name_template='%s_pretesswm',
            position=-1,
        ),
        subjects_dir=dict(),
        test=dict(argstr='-test', ),
    )
    inputs = MRIPretess.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MRIPretess_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = MRIPretess.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..misc import PickAtlas


def test_PickAtlas_inputs():
    input_map = dict(
        atlas=dict(
            extensions=None,
            mandatory=True,
        ),
        dilation_size=dict(usedefault=True, ),
        hemi=dict(usedefault=True, ),
        labels=dict(mandatory=True, ),
        output_file=dict(extensions=None, ),
    )
    inputs = PickAtlas.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_PickAtlas_outputs():
    output_map = dict(mask_file=dict(extensions=None, ), )
    outputs = PickAtlas.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..gtract import gtractResampleCodeImage


def test_gtractResampleCodeImage_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputCodeVolume=dict(
            argstr='--inputCodeVolume %s',
            extensions=None,
        ),
        inputReferenceVolume=dict(
            argstr='--inputReferenceVolume %s',
            extensions=None,
        ),
        inputTransform=dict(
            argstr='--inputTransform %s',
            extensions=None,
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
        transformType=dict(argstr='--transformType %s', ),
    )
    inputs = gtractResampleCodeImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_gtractResampleCodeImage_outputs():
    output_map = dict(outputVolume=dict(extensions=None, ), )
    outputs = gtractResampleCodeImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import MRMath


def test_MRMath_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        axis=dict(argstr='-axis %d', ),
        bval_scale=dict(argstr='-bvalue_scaling %s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        grad_file=dict(
            argstr='-grad %s',
            extensions=None,
            xor=['grad_fsl'],
        ),
        grad_fsl=dict(
            argstr='-fslgrad %s %s',
            xor=['grad_file'],
        ),
        in_bval=dict(extensions=None, ),
        in_bvec=dict(
            argstr='-fslgrad %s %s',
            extensions=None,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-3,
        ),
        nthreads=dict(
            argstr='-nthreads %d',
            nohash=True,
        ),
        operation=dict(
            argstr='%s',
            mandatory=True,
            position=-2,
        ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-1,
        ),
    )
    inputs = MRMath.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MRMath_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = MRMath.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..quickshear import Quickshear


def test_Quickshear_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        buff=dict(
            argstr='%d',
            position=4,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=2,
        ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            keep_extension=True,
            name_source='in_file',
            name_template='%s_defaced',
            position=3,
        ),
    )
    inputs = Quickshear.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Quickshear_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Quickshear.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..gtract import gtractResampleFibers


def test_gtractResampleFibers_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputForwardDeformationFieldVolume=dict(
            argstr='--inputForwardDeformationFieldVolume %s',
            extensions=None,
        ),
        inputReverseDeformationFieldVolume=dict(
            argstr='--inputReverseDeformationFieldVolume %s',
            extensions=None,
        ),
        inputTract=dict(
            argstr='--inputTract %s',
            extensions=None,
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        outputTract=dict(
            argstr='--outputTract %s',
            hash_files=False,
        ),
        writeXMLPolyDataFile=dict(argstr='--writeXMLPolyDataFile ', ),
    )
    inputs = gtractResampleFibers.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_gtractResampleFibers_outputs():
    output_map = dict(outputTract=dict(extensions=None, ), )
    outputs = gtractResampleFibers.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import Autobox


def test_Autobox_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-input %s',
            copyfile=False,
            extensions=None,
            mandatory=True,
        ),
        no_clustering=dict(argstr='-noclust', ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_file',
            name_template='%s_autobox',
        ),
        outputtype=dict(),
        padding=dict(argstr='-npad %d', ),
    )
    inputs = Autobox.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Autobox_outputs():
    output_map = dict(
        out_file=dict(extensions=None, ),
        x_max=dict(),
        x_min=dict(),
        y_max=dict(),
        y_min=dict(),
        z_max=dict(),
        z_min=dict(),
    )
    outputs = Autobox.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import AutoTLRC


def test_AutoTLRC_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        base=dict(
            argstr='-base %s',
            mandatory=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-input %s',
            copyfile=False,
            extensions=None,
            mandatory=True,
        ),
        no_ss=dict(argstr='-no_ss', ),
        outputtype=dict(),
    )
    inputs = AutoTLRC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_AutoTLRC_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = AutoTLRC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..wrappers import Function


def test_Function_inputs():
    input_map = dict(function_str=dict(mandatory=True, ), )
    inputs = Function.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Function_outputs():
    output_map = dict()
    outputs = Function.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import TCat


def test_TCat_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_files=dict(
            argstr=' %s',
            copyfile=False,
            mandatory=True,
            position=-1,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_files',
            name_template='%s_tcat',
        ),
        outputtype=dict(),
        rlt=dict(
            argstr='-rlt%s',
            position=1,
        ),
        verbose=dict(argstr='-verb', ),
    )
    inputs = TCat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_TCat_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = TCat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import BlurInMask


def test_BlurInMask_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        automask=dict(argstr='-automask', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        float_out=dict(argstr='-float', ),
        fwhm=dict(
            argstr='-FWHM %f',
            mandatory=True,
        ),
        in_file=dict(
            argstr='-input %s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        multimask=dict(
            argstr='-Mmask %s',
            extensions=None,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        options=dict(
            argstr='%s',
            position=2,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_file',
            name_template='%s_blur',
            position=-1,
        ),
        outputtype=dict(),
        preserve=dict(argstr='-preserve', ),
    )
    inputs = BlurInMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BlurInMask_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = BlurInMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import BRAINSTransformConvert


def test_BRAINSTransformConvert_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        displacementVolume=dict(
            argstr='--displacementVolume %s',
            hash_files=False,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputTransform=dict(
            argstr='--inputTransform %s',
            extensions=None,
        ),
        outputPrecisionType=dict(argstr='--outputPrecisionType %s', ),
        outputTransform=dict(
            argstr='--outputTransform %s',
            hash_files=False,
        ),
        outputTransformType=dict(argstr='--outputTransformType %s', ),
        referenceVolume=dict(
            argstr='--referenceVolume %s',
            extensions=None,
        ),
    )
    inputs = BRAINSTransformConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BRAINSTransformConvert_outputs():
    output_map = dict(
        displacementVolume=dict(extensions=None, ),
        outputTransform=dict(extensions=None, ),
    )
    outputs = BRAINSTransformConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..image import Rescale


def test_Rescale_inputs():
    input_map = dict(
        in_file=dict(
            extensions=None,
            mandatory=True,
        ),
        invert=dict(),
        percentile=dict(usedefault=True, ),
        ref_file=dict(
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = Rescale.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Rescale_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Rescale.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
